nbxmpp.protocol

Package nbxmpp :: Module protocol |
[hide private]
[frames] | no frames]

# Module protocol

source code

Protocol module contains tools that are needed for processing of xmpp-related data structures, including jabber-objects like JID or different stanzas and sub- stanzas) handling routines

Classes | [hide private]
| NodeProcessed Exception that should be raised by handler when the handling should be stopped
| StreamError Base exception class for stream errors
| BadFormat
| BadNamespacePrefix
| Conflict
| ConnectionTimeout
| HostGone
| HostUnknown
| ImproperAddressing
| InternalServerError
| InvalidFrom
| InvalidID
| InvalidNamespace
| InvalidXML
| NotAuthorized
| PolicyViolation
| RemoteConnectionFailed
| ResourceConstraint
| RestrictedXML
| SeeOtherHost
| SystemShutdown
| UndefinedCondition
| UnsupportedEncoding
| UnsupportedStanzaType
| UnsupportedVersion
| XMLNotWellFormed
| JID JID can be built from string, modified, compared, serialised into string
| BOSHBody <body> tag that wraps usual XMPP stanzas in XMPP over BOSH
| Protocol A "stanza" object class. Contains methods that are common for presences, iqs and messages
| Message XMPP Message stanza - "push" mechanism
| Presence
| Iq XMPP Iq object - get/set dialog mechanism
| Hashes Hash elements for various XEPs as defined in XEP-300
| Acks Acknowledgement elements for Stream Management
| ErrorNode XMPP-style error element
| Error Used to quickly transform received stanza into error reply
| DataField This class is used in the DataForm class to describe the single data item
| DataForm Used for manipulating dataforms in XMPP

Functions | [hide private]
ascii_upper(s) | source code
isResultNode(node) Return true if the node is a positive reply | source code
isErrorNode(node) Return true if the node is a negative reply | source code

Variables | [hide private]
| NS_ACTIVITY = ``'``http://jabber.org/protocol/activity``'``
| NS_ADDRESS = ``'``http://jabber.org/protocol/address``'``
| NS_AGENTS = ``'``jabber:iq:agents``'``
| NS_AMP = ``'``http://jabber.org/protocol/amp``'``
| NS_AMP_ERRORS = ``'``http://jabber.org/protocol/amp#errors``'``
| NS_ARCHIVE = ``'``urn:xmpp:archive``'``
| NS_ARCHIVE_AUTO = ``'``urn:xmpp:archive:auto``'``
| NS_ARCHIVE_MANAGE = ``'``urn:xmpp:archive:manage``'``
| NS_ARCHIVE_MANUAL = ``'``urn:xmpp:archive:manual``'``
| NS_ARCHIVE_PREF = ``'``urn:xmpp:archive:pref``'``
| NS_ATOM = ``'``http://www.w3.org/2005/Atom``'``
| NS_ATTENTION = ``'``urn:xmpp:attention:0``'``
| NS_AUTH = ``'``jabber:iq:auth``'``
| NS_AVATAR = ``'``http://www.xmpp.org/extensions/xep-0084.html#ns-m``...``
| NS_BIND = ``'``urn:ietf:params:xml:ns:xmpp-bind``'``
| NS_BLOCKING = ``'``urn:xmpp:blocking``'``
| NS_BOB = ``'``urn:xmpp:bob``'``
| NS_BOOKMARKS = ``'``storage:bookmarks``'``
| NS_BROWSE = ``'``jabber:iq:browse``'``
| NS_BROWSING = ``'``http://jabber.org/protocol/browsing``'``
| NS_BYTESTREAM = ``'``http://jabber.org/protocol/bytestreams``'``
| NS_CAPS = ``'``http://jabber.org/protocol/caps``'``
| NS_CAPTCHA = ``'``urn:xmpp:captcha``'``
| NS_CARBONS = ``'``urn:xmpp:carbons:2``'``
| NS_CHATSTATES = ``'``http://jabber.org/protocol/chatstates``'``
| NS_CHATTING = ``'``http://jabber.org/protocol/chatting``'``
| NS_CLIENT = ``'``jabber:client``'``
| NS_CONDITIONS = ``'``urn:xmpp:muc:conditions:0``'``
| NS_COMMANDS = ``'``http://jabber.org/protocol/commands``'``
| NS_COMPONENT_ACCEPT = ``'``jabber:component:accept``'``
| NS_COMPONENT_1 = ``'``http://jabberd.jabberstudio.org/ns/component``...``
| NS_COMPRESS = ``'``http://jabber.org/protocol/compress``'``
| NS_CONFERENCE = ``'``jabber:x:conference``'``
| NS_CORRECT = ``'``urn:xmpp:message-correct:0``'``
| NS_DATA = ``'``jabber:x:data``'``
| NS_DATA_MEDIA = ``'``urn:xmpp:media-element``'``
| NS_DELAY = ``'``jabber:x:delay``'``
| NS_DELAY2 = ``'``urn:xmpp:delay``'``
| NS_DIALBACK = ``'``jabber:server:dialback``'``
| NS_DISCO = ``'``http://jabber.org/protocol/disco``'``
| NS_DISCO_INFO = ``'``http://jabber.org/protocol/disco#info``'``
| NS_DISCO_ITEMS = ``'``http://jabber.org/protocol/disco#items``'``
| NS_ENCRYPTED = ``'``jabber:x:encrypted``'``
| NS_ESESSION = ``'``http://www.xmpp.org/extensions/xep-0116.html#ns``'``
| NS_ESESSION_INIT = ``'``http://www.xmpp.org/extensions/xep-0116.ht``...``
| NS_EVENT = ``'``jabber:x:event``'``
| NS_FEATURE = ``'``http://jabber.org/protocol/feature-neg``'``
| NS_FILE = ``'``http://jabber.org/protocol/si/profile/file-transfer``'``
| NS_FORWARD = ``'``urn:xmpp:forward:0``'``
| NS_GAMING = ``'``http://jabber.org/protocol/gaming``'``
| NS_GATEWAY = ``'``jabber:iq:gateway``'``
| NS_GEOLOC = ``'``http://jabber.org/protocol/geoloc``'``
| NS_GROUPCHAT = ``'``gc-1.0``'``
| NS_HTTP_AUTH = ``'``http://jabber.org/protocol/http-auth``'``
| NS_HTTP_BIND = ``'``http://jabber.org/protocol/httpbind``'``
| NS_IBB = ``'``http://jabber.org/protocol/ibb``'``
| NS_INVISIBLE = ``'``presence-invisible``'``
| NS_IQ = ``'``iq``'``
| NS_JINGLE = ``'``urn:xmpp:jingle:1``'``
| NS_JINGLE_ERRORS = ``'``urn:xmpp:jingle:errors:1``'``
| NS_JINGLE_RTP = ``'``urn:xmpp:jingle:apps:rtp:1``'``
| NS_JINGLE_RTP_AUDIO = ``'``urn:xmpp:jingle:apps:rtp:audio``'``
| NS_JINGLE_RTP_VIDEO = ``'``urn:xmpp:jingle:apps:rtp:video``'``
| NS_JINGLE_FILE_TRANSFER = ``'``urn:xmpp:jingle:apps:file-transfer:3``'``
| NS_JINGLE_XTLS = ``'``urn:xmpp:jingle:security:xtls:0``'``
| NS_JINGLE_RAW_UDP = ``'``urn:xmpp:jingle:transports:raw-udp:1``'``
| NS_JINGLE_ICE_UDP = ``'``urn:xmpp:jingle:transports:ice-udp:1``'``
| NS_JINGLE_BYTESTREAM = ``'``urn:xmpp:jingle:transports:s5b:1``'``
| NS_JINGLE_IBB = ``'``urn:xmpp:jingle:transports:ibb:1``'``
| NS_LAST = ``'``jabber:iq:last``'``
| NS_LOCATION = ``'``http://jabber.org/protocol/geoloc``'``
| NS_MAM = ``'``urn:xmpp:mam:tmp``'``
| NS_MESSAGE = ``'``message``'``
| NS_MOOD = ``'``http://jabber.org/protocol/mood``'``
| NS_MUC = ``'``http://jabber.org/protocol/muc``'``
| NS_MUC_USER = ``'``http://jabber.org/protocol/muc#user``'``
| NS_MUC_ADMIN = ``'``http://jabber.org/protocol/muc#admin``'``
| NS_MUC_OWNER = ``'``http://jabber.org/protocol/muc#owner``'``
| NS_MUC_UNIQUE = ``'``http://jabber.org/protocol/muc#unique``'``
| NS_MUC_CONFIG = ``'``http://jabber.org/protocol/muc#roomconfig``'``
| NS_NICK = ``'``http://jabber.org/protocol/nick``'``
| NS_OFFLINE = ``'``http://www.jabber.org/jeps/jep-0030.html``'``
| NS_PHYSLOC = ``'``http://jabber.org/protocol/physloc``'``
| NS_PING = ``'``urn:xmpp:ping``'``
| NS_PRESENCE = ``'``presence``'``
| NS_PRIVACY = ``'``jabber:iq:privacy``'``
| NS_PRIVATE = ``'``jabber:iq:private``'``
| NS_PROFILE = ``'``http://jabber.org/protocol/profile``'``
| NS_PUBSUB = ``'``http://jabber.org/protocol/pubsub``'``
| NS_PUBSUB_EVENT = ``'``http://jabber.org/protocol/pubsub#event``'``
| NS_PUBSUB_PUBLISH_OPTIONS = ``'``http://jabber.org/protocol/pubsub``...``
| NS_PUBSUB_OWNER = ``'``http://jabber.org/protocol/pubsub#owner``'``
| NS_REGISTER = ``'``jabber:iq:register``'``
| NS_ROSTER = ``'``jabber:iq:roster``'``
| NS_ROSTERNOTES = ``'``storage:rosternotes``'``
| NS_ROSTERX = ``'``http://jabber.org/protocol/rosterx``'``
| NS_ROSTER_VER = ``'``urn:xmpp:features:rosterver``'``
| NS_RPC = ``'``jabber:iq:rpc``'``
| NS_RSM = ``'``http://jabber.org/protocol/rsm``'``
| NS_SASL = ``'``urn:ietf:params:xml:ns:xmpp-sasl``'``
| NS_SECLABEL = ``'``urn:xmpp:sec-label:0``'``
| NS_SECLABEL_CATALOG = ``'``urn:xmpp:sec-label:catalog:2``'``
| NS_SEARCH = ``'``jabber:iq:search``'``
| NS_SERVER = ``'``jabber:server``'``
| NS_SESSION = ``'``urn:ietf:params:xml:ns:xmpp-session``'``
| NS_SI = ``'``http://jabber.org/protocol/si``'``
| NS_SI_PUB = ``'``http://jabber.org/protocol/sipub``'``
| NS_SIGNED = ``'``jabber:x:signed``'``
| NS_SSN = ``'``urn:xmpp:ssn``'``
| NS_STANZA_CRYPTO = ``'``http://www.xmpp.org/extensions/xep-0200.ht``...``
| NS_STANZAS = ``'``urn:ietf:params:xml:ns:xmpp-stanzas``'``
| NS_STREAM = ``'``http://affinix.com/jabber/stream``'``
| NS_STREAMS = ``'``http://etherx.jabber.org/streams``'``
| NS_TIME = ``'``jabber:iq:time``'``
| NS_TIME_REVISED = ``'``urn:xmpp:time``'``
| NS_TLS = ``'``urn:ietf:params:xml:ns:xmpp-tls``'``
| NS_TUNE = ``'``http://jabber.org/protocol/tune``'``
| NS_VACATION = ``'``http://jabber.org/protocol/vacation``'``
| NS_VCARD = ``'``vcard-temp``'``
| NS_GMAILNOTIFY = ``'``google:mail:notify``'``
| NS_GTALKSETTING = ``'``google:setting``'``
| NS_VCARD_UPDATE = ``'``vcard-temp:x:update``'``
| NS_VERSION = ``'``jabber:iq:version``'``
| NS_VIEWING = ``'``http://jabber.org/protocol/viewing``'``
| NS_WAITINGLIST = ``'``http://jabber.org/protocol/waitinglist``'``
| NS_XHTML_IM = ``'``http://jabber.org/protocol/xhtml-im``'``
| NS_XHTML = ``'``http://www.w3.org/1999/xhtml``'``
| NS_X_OOB = ``'``jabber:x:oob``'``
| NS_DATA_LAYOUT = ``'``http://jabber.org/protocol/xdata-layout``'``
| NS_DATA_VALIDATE = ``'``http://jabber.org/protocol/xdata-validate``'``
| NS_XMPP_STREAMS = ``'``urn:ietf:params:xml:ns:xmpp-streams``'``
| NS_RECEIPTS = ``'``urn:xmpp:receipts``'``
| NS_PUBKEY_PUBKEY = ``'``urn:xmpp:pubkey:2``'``
| NS_PUBKEY_REVOKE = ``'``urn:xmpp:revoke:2``'``
| NS_PUBKEY_ATTEST = ``'``urn:xmpp:attest:2``'``
| NS_STREAM_MGMT = ``'``urn:xmpp:sm:2``'``
| NS_HASHES = ``'``urn:xmpp:hashes:1``'``
| NS_HASHES_MD5 = ``'``urn:xmpp:hash-function-textual-names:md5``'``
| NS_HASHES_SHA1 = ``'``urn:xmpp:hash-function-textual-names:sha-1``'``
| NS_HASHES_SHA256 = ``'``urn:xmpp:hash-function-textual-names:sha-256``'``
| NS_HASHES_SHA512 = ``'``urn:xmpp:hash-function-textual-names:sha-512``'``
| ERRORS = ``{``'``urn:ietf:params:xml:ns:xmpp-sasl aborted``'``:` `[``'````'``,` `'````'``,``...``
| _errorcodes = ``{``'``302``'``:` `'``redirect``'``,` `'``400``'``:` `'``unexpected-request``'``,``...``
| STREAM_NOT_AUTHORIZED = ``'``urn:ietf:params:xml:ns:xmpp-streams n``...``
| STREAM_REMOTE_CONNECTION_FAILED = ``'``urn:ietf:params:xml:ns:xmpp``...``
| SASL_MECHANISM_TOO_WEAK = ``'``urn:ietf:params:xml:ns:xmpp-sasl me``...``
| STREAM_XML_NOT_WELL_FORMED = ``'``urn:ietf:params:xml:ns:xmpp-stre``...``
| ERR_JID_MALFORMED = ``'``urn:ietf:params:xml:ns:xmpp-stanzas jid-m``...``
| STREAM_SEE_OTHER_HOST = ``'``urn:ietf:params:xml:ns:xmpp-streams s``...``
| STREAM_BAD_NAMESPACE_PREFIX = ``'``urn:ietf:params:xml:ns:xmpp-str``...``
| ERR_SERVICE_UNAVAILABLE = ``'``urn:ietf:params:xml:ns:xmpp-stanzas``...``
| STREAM_CONNECTION_TIMEOUT = ``'``urn:ietf:params:xml:ns:xmpp-strea``...``
| STREAM_UNSUPPORTED_VERSION = ``'``urn:ietf:params:xml:ns:xmpp-stre``...``
| STREAM_IMPROPER_ADDRESSING = ``'``urn:ietf:params:xml:ns:xmpp-stre``...``
| STREAM_UNDEFINED_CONDITION = ``'``urn:ietf:params:xml:ns:xmpp-stre``...``
| SASL_NOT_AUTHORIZED = ``'``urn:ietf:params:xml:ns:xmpp-sasl not-au``...``
| ERR_GONE = ``'``urn:ietf:params:xml:ns:xmpp-stanzas gone``'``
| SASL_TEMPORARY_AUTH_FAILURE = ``'``urn:ietf:params:xml:ns:xmpp-sas``...``
| ERR_REMOTE_SERVER_NOT_FOUND = ``'``urn:ietf:params:xml:ns:xmpp-sta``...``
| ERR_UNEXPECTED_REQUEST = ``'``urn:ietf:params:xml:ns:xmpp-stanzas` `...``
| ERR_RECIPIENT_UNAVAILABLE = ``'``urn:ietf:params:xml:ns:xmpp-stanz``...``
| ERR_CONFLICT = ``'``urn:ietf:params:xml:ns:xmpp-stanzas conflict``'``
| STREAM_SYSTEM_SHUTDOWN = ``'``urn:ietf:params:xml:ns:xmpp-streams` `...``
| STREAM_BAD_FORMAT = ``'``urn:ietf:params:xml:ns:xmpp-streams bad-f``...``
| ERR_SUBSCRIPTION_REQUIRED = ``'``urn:ietf:params:xml:ns:xmpp-stanz``...``
| STREAM_INTERNAL_SERVER_ERROR = ``'``urn:ietf:params:xml:ns:xmpp-st``...``
| ERR_NOT_AUTHORIZED = ``'``urn:ietf:params:xml:ns:xmpp-stanzas not-``...``
| SASL_ABORTED = ``'``urn:ietf:params:xml:ns:xmpp-sasl aborted``'``
| ERR_REGISTRATION_REQUIRED = ``'``urn:ietf:params:xml:ns:xmpp-stanz``...``
| ERR_INTERNAL_SERVER_ERROR = ``'``urn:ietf:params:xml:ns:xmpp-stanz``...``
| SASL_INCORRECT_ENCODING = ``'``urn:ietf:params:xml:ns:xmpp-sasl in``...``
| STREAM_HOST_GONE = ``'``urn:ietf:params:xml:ns:xmpp-streams host-g``...``
| STREAM_POLICY_VIOLATION = ``'``urn:ietf:params:xml:ns:xmpp-streams``...``
| STREAM_INVALID_XML = ``'``urn:ietf:params:xml:ns:xmpp-streams inva``...``
| STREAM_CONFLICT = ``'``urn:ietf:params:xml:ns:xmpp-streams conflict``'``
| STREAM_RESOURCE_CONSTRAINT = ``'``urn:ietf:params:xml:ns:xmpp-stre``...``
| STREAM_UNSUPPORTED_ENCODING = ``'``urn:ietf:params:xml:ns:xmpp-str``...``
| ERR_NOT_ALLOWED = ``'``urn:ietf:params:xml:ns:xmpp-stanzas not-all``...``
| ERR_ITEM_NOT_FOUND = ``'``urn:ietf:params:xml:ns:xmpp-stanzas item``...``
| ERR_NOT_ACCEPTABLE = ``'``urn:ietf:params:xml:ns:xmpp-stanzas not-``...``
| STREAM_INVALID_FROM = ``'``urn:ietf:params:xml:ns:xmpp-streams inv``...``
| ERR_FEATURE_NOT_IMPLEMENTED = ``'``urn:ietf:params:xml:ns:xmpp-sta``...``
| ERR_BAD_REQUEST = ``'``urn:ietf:params:xml:ns:xmpp-stanzas bad-req``...``
| STREAM_INVALID_ID = ``'``urn:ietf:params:xml:ns:xmpp-streams inval``...``
| STREAM_HOST_UNKNOWN = ``'``urn:ietf:params:xml:ns:xmpp-streams hos``...``
| ERR_UNDEFINED_CONDITION = ``'``urn:ietf:params:xml:ns:xmpp-stanzas``...``
| SASL_INVALID_MECHANISM = ``'``urn:ietf:params:xml:ns:xmpp-sasl inv``...``
| STREAM_RESTRICTED_XML = ``'``urn:ietf:params:xml:ns:xmpp-streams r``...``
| ERR_RESOURCE_CONSTRAINT = ``'``urn:ietf:params:xml:ns:xmpp-stanzas``...``
| ERR_REMOTE_SERVER_TIMEOUT = ``'``urn:ietf:params:xml:ns:xmpp-stanz``...``
| SASL_INVALID_AUTHZID = ``'``urn:ietf:params:xml:ns:xmpp-sasl inval``...``
| ERR_PAYMENT_REQUIRED = ``'``urn:ietf:params:xml:ns:xmpp-stanzas pa``...``
| STREAM_INVALID_NAMESPACE = ``'``urn:ietf:params:xml:ns:xmpp-stream``...``
| ERR_REDIRECT = ``'``urn:ietf:params:xml:ns:xmpp-stanzas redirect``'``
| STREAM_UNSUPPORTED_STANZA_TYPE = ``'``urn:ietf:params:xml:ns:xmpp-``...``
| ERR_FORBIDDEN = ``'``urn:ietf:params:xml:ns:xmpp-stanzas forbidden``'``
| stream_exceptions = ``{``'``bad-format``'``:` <class 'nbxmpp.protocol.Bad`...``
| __package__ = ``'``nbxmpp``'``

Imports: Node, NodeBuilder, time, string, hashlib

Function Details | [hide private]

### ascii_upper(s) | source code

### isResultNode(node) | source code
Return true if the node is a positive reply

### isErrorNode(node) | source code
Return true if the node is a negative reply

Variables Details | [hide private]

  ### NS_ACTIVITY Value:
      'http://jabber.org/protocol/activity'

  ### NS_ADDRESS Value:
      'http://jabber.org/protocol/address'

  ### NS_AGENTS Value:
      'jabber:iq:agents'

  ### NS_AMP Value:
      'http://jabber.org/protocol/amp'

  ### NS_AMP_ERRORS Value:
      'http://jabber.org/protocol/amp#errors'

  ### NS_ARCHIVE Value:
      'urn:xmpp:archive'

  ### NS_ARCHIVE_AUTO Value:
      'urn:xmpp:archive:auto'

  ### NS_ARCHIVE_MANAGE Value:
      'urn:xmpp:archive:manage'

  ### NS_ARCHIVE_MANUAL Value:
      'urn:xmpp:archive:manual'

  ### NS_ARCHIVE_PREF Value:
      'urn:xmpp:archive:pref'

  ### NS_ATOM Value:
      'http://www.w3.org/2005/Atom'

  ### NS_ATTENTION Value:
      'urn:xmpp:attention:0'

  ### NS_AUTH Value:
      'jabber:iq:auth'

  ### NS_AVATAR Value:
      'http://www.xmpp.org/extensions/xep-0084.html#ns-metadata'

  ### NS_BIND Value:
      'urn:ietf:params:xml:ns:xmpp-bind'

  ### NS_BLOCKING Value:
      'urn:xmpp:blocking'

  ### NS_BOB Value:
      'urn:xmpp:bob'

  ### NS_BOOKMARKS Value:
      'storage:bookmarks'

  ### NS_BROWSE Value:
      'jabber:iq:browse'

  ### NS_BROWSING Value:
      'http://jabber.org/protocol/browsing'

  ### NS_BYTESTREAM Value:
      'http://jabber.org/protocol/bytestreams'

  ### NS_CAPS Value:
      'http://jabber.org/protocol/caps'

  ### NS_CAPTCHA Value:
      'urn:xmpp:captcha'

  ### NS_CARBONS Value:
      'urn:xmpp:carbons:2'

  ### NS_CHATSTATES Value:
      'http://jabber.org/protocol/chatstates'

  ### NS_CHATTING Value:
      'http://jabber.org/protocol/chatting'

  ### NS_CLIENT Value:
      'jabber:client'

  ### NS_CONDITIONS Value:
      'urn:xmpp:muc:conditions:0'

  ### NS_COMMANDS Value:
      'http://jabber.org/protocol/commands'

  ### NS_COMPONENT_ACCEPT Value:
      'jabber:component:accept'

  ### NS_COMPONENT_1 Value:
      'http://jabberd.jabberstudio.org/ns/component/1.0'

  ### NS_COMPRESS Value:
      'http://jabber.org/protocol/compress'

  ### NS_CONFERENCE Value:
      'jabber:x:conference'

  ### NS_CORRECT Value:
      'urn:xmpp:message-correct:0'

  ### NS_DATA Value:
      'jabber:x:data'

  ### NS_DATA_MEDIA Value:
      'urn:xmpp:media-element'

  ### NS_DELAY Value:
      'jabber:x:delay'

  ### NS_DELAY2 Value:
      'urn:xmpp:delay'

  ### NS_DIALBACK Value:
      'jabber:server:dialback'

  ### NS_DISCO Value:
      'http://jabber.org/protocol/disco'

  ### NS_DISCO_INFO Value:
      'http://jabber.org/protocol/disco#info'

  ### NS_DISCO_ITEMS Value:
      'http://jabber.org/protocol/disco#items'

  ### NS_ENCRYPTED Value:
      'jabber:x:encrypted'

  ### NS_ESESSION Value:
      'http://www.xmpp.org/extensions/xep-0116.html#ns'

  ### NS_ESESSION_INIT Value:
      'http://www.xmpp.org/extensions/xep-0116.html#ns-init'

  ### NS_EVENT Value:
      'jabber:x:event'

  ### NS_FEATURE Value:
      'http://jabber.org/protocol/feature-neg'

  ### NS_FILE Value:
      'http://jabber.org/protocol/si/profile/file-transfer'

  ### NS_FORWARD Value:
      'urn:xmpp:forward:0'

  ### NS_GAMING Value:
      'http://jabber.org/protocol/gaming'

  ### NS_GATEWAY Value:
      'jabber:iq:gateway'

  ### NS_GEOLOC Value:
      'http://jabber.org/protocol/geoloc'

  ### NS_GROUPCHAT Value:
      'gc-1.0'

  ### NS_HTTP_AUTH Value:
      'http://jabber.org/protocol/http-auth'

  ### NS_HTTP_BIND Value:
      'http://jabber.org/protocol/httpbind'

  ### NS_IBB Value:
      'http://jabber.org/protocol/ibb'

  ### NS_INVISIBLE Value:
      'presence-invisible'

  ### NS_IQ Value:
      'iq'

  ### NS_JINGLE Value:
      'urn:xmpp:jingle:1'

  ### NS_JINGLE_ERRORS Value:
      'urn:xmpp:jingle:errors:1'

  ### NS_JINGLE_RTP Value:
      'urn:xmpp:jingle:apps:rtp:1'

  ### NS_JINGLE_RTP_AUDIO Value:
      'urn:xmpp:jingle:apps:rtp:audio'

  ### NS_JINGLE_RTP_VIDEO Value:
      'urn:xmpp:jingle:apps:rtp:video'

  ### NS_JINGLE_FILE_TRANSFER Value:
      'urn:xmpp:jingle:apps:file-transfer:3'

  ### NS_JINGLE_XTLS Value:
      'urn:xmpp:jingle:security:xtls:0'

  ### NS_JINGLE_RAW_UDP Value:
      'urn:xmpp:jingle:transports:raw-udp:1'

  ### NS_JINGLE_ICE_UDP Value:
      'urn:xmpp:jingle:transports:ice-udp:1'

  ### NS_JINGLE_BYTESTREAM Value:
      'urn:xmpp:jingle:transports:s5b:1'

  ### NS_JINGLE_IBB Value:
      'urn:xmpp:jingle:transports:ibb:1'

  ### NS_LAST Value:
      'jabber:iq:last'

  ### NS_LOCATION Value:
      'http://jabber.org/protocol/geoloc'

  ### NS_MAM Value:
      'urn:xmpp:mam:tmp'

  ### NS_MESSAGE Value:
      'message'

  ### NS_MOOD Value:
      'http://jabber.org/protocol/mood'

  ### NS_MUC Value:
      'http://jabber.org/protocol/muc'

  ### NS_MUC_USER Value:
      'http://jabber.org/protocol/muc#user'

  ### NS_MUC_ADMIN Value:
      'http://jabber.org/protocol/muc#admin'

  ### NS_MUC_OWNER Value:
      'http://jabber.org/protocol/muc#owner'

  ### NS_MUC_UNIQUE Value:
      'http://jabber.org/protocol/muc#unique'

  ### NS_MUC_CONFIG Value:
      'http://jabber.org/protocol/muc#roomconfig'

  ### NS_NICK Value:
      'http://jabber.org/protocol/nick'

  ### NS_OFFLINE Value:
      'http://www.jabber.org/jeps/jep-0030.html'

  ### NS_PHYSLOC Value:
      'http://jabber.org/protocol/physloc'

  ### NS_PING Value:
      'urn:xmpp:ping'

  ### NS_PRESENCE Value:
      'presence'

  ### NS_PRIVACY Value:
      'jabber:iq:privacy'

  ### NS_PRIVATE Value:
      'jabber:iq:private'

  ### NS_PROFILE Value:
      'http://jabber.org/protocol/profile'

  ### NS_PUBSUB Value:
      'http://jabber.org/protocol/pubsub'

  ### NS_PUBSUB_EVENT Value:
      'http://jabber.org/protocol/pubsub#event'

  ### NS_PUBSUB_PUBLISH_OPTIONS Value:
      'http://jabber.org/protocol/pubsub#publish-options'

  ### NS_PUBSUB_OWNER Value:
      'http://jabber.org/protocol/pubsub#owner'

  ### NS_REGISTER Value:
      'jabber:iq:register'

  ### NS_ROSTER Value:
      'jabber:iq:roster'

  ### NS_ROSTERNOTES Value:
      'storage:rosternotes'

  ### NS_ROSTERX Value:
      'http://jabber.org/protocol/rosterx'

  ### NS_ROSTER_VER Value:
      'urn:xmpp:features:rosterver'

  ### NS_RPC Value:
      'jabber:iq:rpc'

  ### NS_RSM Value:
      'http://jabber.org/protocol/rsm'

  ### NS_SASL Value:
      'urn:ietf:params:xml:ns:xmpp-sasl'

  ### NS_SECLABEL Value:
      'urn:xmpp:sec-label:0'

  ### NS_SECLABEL_CATALOG Value:
      'urn:xmpp:sec-label:catalog:2'

  ### NS_SEARCH Value:
      'jabber:iq:search'

  ### NS_SERVER Value:
      'jabber:server'

  ### NS_SESSION Value:
      'urn:ietf:params:xml:ns:xmpp-session'

  ### NS_SI Value:
      'http://jabber.org/protocol/si'

  ### NS_SI_PUB Value:
      'http://jabber.org/protocol/sipub'

  ### NS_SIGNED Value:
      'jabber:x:signed'

  ### NS_SSN Value:
      'urn:xmpp:ssn'

  ### NS_STANZA_CRYPTO Value:
      'http://www.xmpp.org/extensions/xep-0200.html#ns'

  ### NS_STANZAS Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas'

  ### NS_STREAM Value:
      'http://affinix.com/jabber/stream'

  ### NS_STREAMS Value:
      'http://etherx.jabber.org/streams'

  ### NS_TIME Value:
      'jabber:iq:time'

  ### NS_TIME_REVISED Value:
      'urn:xmpp:time'

  ### NS_TLS Value:
      'urn:ietf:params:xml:ns:xmpp-tls'

  ### NS_TUNE Value:
      'http://jabber.org/protocol/tune'

  ### NS_VACATION Value:
      'http://jabber.org/protocol/vacation'

  ### NS_VCARD Value:
      'vcard-temp'

  ### NS_GMAILNOTIFY Value:
      'google:mail:notify'

  ### NS_GTALKSETTING Value:
      'google:setting'

  ### NS_VCARD_UPDATE Value:
      'vcard-temp:x:update'

  ### NS_VERSION Value:
      'jabber:iq:version'

  ### NS_VIEWING Value:
      'http://jabber.org/protocol/viewing'

  ### NS_WAITINGLIST Value:
      'http://jabber.org/protocol/waitinglist'

  ### NS_XHTML_IM Value:
      'http://jabber.org/protocol/xhtml-im'

  ### NS_XHTML Value:
      'http://www.w3.org/1999/xhtml'

  ### NS_X_OOB Value:
      'jabber:x:oob'

  ### NS_DATA_LAYOUT Value:
      'http://jabber.org/protocol/xdata-layout'

  ### NS_DATA_VALIDATE Value:
      'http://jabber.org/protocol/xdata-validate'

  ### NS_XMPP_STREAMS Value:
      'urn:ietf:params:xml:ns:xmpp-streams'

  ### NS_RECEIPTS Value:
      'urn:xmpp:receipts'

  ### NS_PUBKEY_PUBKEY Value:
      'urn:xmpp:pubkey:2'

  ### NS_PUBKEY_REVOKE Value:
      'urn:xmpp:revoke:2'

  ### NS_PUBKEY_ATTEST Value:
      'urn:xmpp:attest:2'

  ### NS_STREAM_MGMT Value:
      'urn:xmpp:sm:2'

  ### NS_HASHES Value:
      'urn:xmpp:hashes:1'

  ### NS_HASHES_MD5 Value:
      'urn:xmpp:hash-function-textual-names:md5'

  ### NS_HASHES_SHA1 Value:
      'urn:xmpp:hash-function-textual-names:sha-1'

  ### NS_HASHES_SHA256 Value:
      'urn:xmpp:hash-function-textual-names:sha-256'

  ### NS_HASHES_SHA512 Value:
      'urn:xmpp:hash-function-textual-names:sha-512'

  ### ERRORS Value:
      {'urn:ietf:params:xml:ns:xmpp-sasl aborted': ['',
                                                    '',
                                                    'The receiving entity ac
      knowledges an <abort/> element sent by the initiating entity; sent in
      reply to the <abort/> element.'],
       'urn:ietf:params:xml:ns:xmpp-sasl incorrect-encoding': ['',
                                                               '',
                                                               'The data pro
      ...

  ### _errorcodes Value:
      {'302': 'redirect',
       '400': 'unexpected-request',
       '401': 'not-authorized',
       '402': 'payment-required',
       '403': 'forbidden',
       '404': 'remote-server-not-found',
       '405': 'not-allowed',
       '406': 'not-acceptable',
      ...

  ### STREAM_NOT_AUTHORIZED Value:
      'urn:ietf:params:xml:ns:xmpp-streams not-authorized'

  ### STREAM_REMOTE_CONNECTION_FAILED Value:
      'urn:ietf:params:xml:ns:xmpp-streams remote-connection-failed'

  ### SASL_MECHANISM_TOO_WEAK Value:
      'urn:ietf:params:xml:ns:xmpp-sasl mechanism-too-weak'

  ### STREAM_XML_NOT_WELL_FORMED Value:
      'urn:ietf:params:xml:ns:xmpp-streams xml-not-well-formed'

  ### ERR_JID_MALFORMED Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas jid-malformed'

  ### STREAM_SEE_OTHER_HOST Value:
      'urn:ietf:params:xml:ns:xmpp-streams see-other-host'

  ### STREAM_BAD_NAMESPACE_PREFIX Value:
      'urn:ietf:params:xml:ns:xmpp-streams bad-namespace-prefix'

  ### ERR_SERVICE_UNAVAILABLE Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas service-unavailable'

  ### STREAM_CONNECTION_TIMEOUT Value:
      'urn:ietf:params:xml:ns:xmpp-streams connection-timeout'

  ### STREAM_UNSUPPORTED_VERSION Value:
      'urn:ietf:params:xml:ns:xmpp-streams unsupported-version'

  ### STREAM_IMPROPER_ADDRESSING Value:
      'urn:ietf:params:xml:ns:xmpp-streams improper-addressing'

  ### STREAM_UNDEFINED_CONDITION Value:
      'urn:ietf:params:xml:ns:xmpp-streams undefined-condition'

  ### SASL_NOT_AUTHORIZED Value:
      'urn:ietf:params:xml:ns:xmpp-sasl not-authorized'

  ### ERR_GONE Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas gone'

  ### SASL_TEMPORARY_AUTH_FAILURE Value:
      'urn:ietf:params:xml:ns:xmpp-sasl temporary-auth-failure'

  ### ERR_REMOTE_SERVER_NOT_FOUND Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas remote-server-not-found'

  ### ERR_UNEXPECTED_REQUEST Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas unexpected-request'

  ### ERR_RECIPIENT_UNAVAILABLE Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas recipient-unavailable'

  ### ERR_CONFLICT Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas conflict'

  ### STREAM_SYSTEM_SHUTDOWN Value:
      'urn:ietf:params:xml:ns:xmpp-streams system-shutdown'

  ### STREAM_BAD_FORMAT Value:
      'urn:ietf:params:xml:ns:xmpp-streams bad-format'

  ### ERR_SUBSCRIPTION_REQUIRED Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas subscription-required'

  ### STREAM_INTERNAL_SERVER_ERROR Value:
      'urn:ietf:params:xml:ns:xmpp-streams internal-server-error'

  ### ERR_NOT_AUTHORIZED Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas not-authorized'

  ### SASL_ABORTED Value:
      'urn:ietf:params:xml:ns:xmpp-sasl aborted'

  ### ERR_REGISTRATION_REQUIRED Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas registration-required'

  ### ERR_INTERNAL_SERVER_ERROR Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas internal-server-error'

  ### SASL_INCORRECT_ENCODING Value:
      'urn:ietf:params:xml:ns:xmpp-sasl incorrect-encoding'

  ### STREAM_HOST_GONE Value:
      'urn:ietf:params:xml:ns:xmpp-streams host-gone'

  ### STREAM_POLICY_VIOLATION Value:
      'urn:ietf:params:xml:ns:xmpp-streams policy-violation'

  ### STREAM_INVALID_XML Value:
      'urn:ietf:params:xml:ns:xmpp-streams invalid-xml'

  ### STREAM_CONFLICT Value:
      'urn:ietf:params:xml:ns:xmpp-streams conflict'

  ### STREAM_RESOURCE_CONSTRAINT Value:
      'urn:ietf:params:xml:ns:xmpp-streams resource-constraint'

  ### STREAM_UNSUPPORTED_ENCODING Value:
      'urn:ietf:params:xml:ns:xmpp-streams unsupported-encoding'

  ### ERR_NOT_ALLOWED Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas not-allowed'

  ### ERR_ITEM_NOT_FOUND Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas item-not-found'

  ### ERR_NOT_ACCEPTABLE Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas not-acceptable'

  ### STREAM_INVALID_FROM Value:
      'urn:ietf:params:xml:ns:xmpp-streams invalid-from'

  ### ERR_FEATURE_NOT_IMPLEMENTED Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas feature-not-implemented'

  ### ERR_BAD_REQUEST Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas bad-request'

  ### STREAM_INVALID_ID Value:
      'urn:ietf:params:xml:ns:xmpp-streams invalid-id'

  ### STREAM_HOST_UNKNOWN Value:
      'urn:ietf:params:xml:ns:xmpp-streams host-unknown'

  ### ERR_UNDEFINED_CONDITION Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas undefined-condition'

  ### SASL_INVALID_MECHANISM Value:
      'urn:ietf:params:xml:ns:xmpp-sasl invalid-mechanism'

  ### STREAM_RESTRICTED_XML Value:
      'urn:ietf:params:xml:ns:xmpp-streams restricted-xml'

  ### ERR_RESOURCE_CONSTRAINT Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas resource-constraint'

  ### ERR_REMOTE_SERVER_TIMEOUT Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas remote-server-timeout'

  ### SASL_INVALID_AUTHZID Value:
      'urn:ietf:params:xml:ns:xmpp-sasl invalid-authzid'

  ### ERR_PAYMENT_REQUIRED Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas payment-required'

  ### STREAM_INVALID_NAMESPACE Value:
      'urn:ietf:params:xml:ns:xmpp-streams invalid-namespace'

  ### ERR_REDIRECT Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas redirect'

  ### STREAM_UNSUPPORTED_STANZA_TYPE Value:
      'urn:ietf:params:xml:ns:xmpp-streams unsupported-stanza-type'

  ### ERR_FORBIDDEN Value:
      'urn:ietf:params:xml:ns:xmpp-stanzas forbidden'

  ### stream_exceptions Value:
      {'bad-format': <class 'nbxmpp.protocol.BadFormat'>,
       'bad-namespace-prefix': <class 'nbxmpp.protocol.BadNamespacePrefix'>,
       'conflict': <class 'nbxmpp.protocol.Conflict'>,
       'connection-timeout': <class 'nbxmpp.protocol.ConnectionTimeout'>,
       'host-gone': <class 'nbxmpp.protocol.HostGone'>,
       'host-unknown': <class 'nbxmpp.protocol.HostUnknown'>,
       'improper-addressing': <class 'nbxmpp.protocol.ImproperAddressing'>,
       'internal-server-error': <class 'nbxmpp.protocol.InternalServerError'
      ...

  ### __package__ Value:
      'nbxmpp'